==> audio_player_chopinzinhofm-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:audio_player_chopinzinhofm/audio_player_chopinzinhofm.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await AudioPlayerChopinzinhofm.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      home: new Scaffold(
        appBar: new AppBar(
          title: const Text('Plugin example app'),
        ),
        body: InkWell(
            child: Stack(
          children: <Widget>[
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceAround,
                  children: <Widget>[
                    FlatButton(
                        onPressed: () {
                          AudioPlayerChopinzinhofm.pauseAudio;
                        },
                        child: Text('Pause')),
                    FlatButton(
                        onPressed: () {
                          AudioPlayerChopinzinhofm.startAudio;
                        },
                        child: Text('Play')),
                    FlatButton(
                        onPressed: () {
                          AudioPlayerChopinzinhofm.stopAudio;
                        },
                        child: Text('Stop')),
                  ],
                )
              ],
            ),
          ],
        )),
      ),
    );
  }
}

==> audio_player_chopinzinhofm-0.0.6.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:audio_player_chopinzinhofm/audio_player_chopinzinhofm.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
  }


  @override
  Widget build(BuildContext context) {
    String status = 'Demo app';
        return new MaterialApp(
          home: new Scaffold(
            appBar: new AppBar(
              title: new Text(status),
        ),
        body: InkWell(
            child: Stack(
          children: <Widget>[
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceAround,
                  children: <Widget>[
                    FlatButton(
                        onPressed: () {
                          AudioPlayerChopinzinhofm.pauseAudio;
                        },
                        child: Text('Pause')),
                    FlatButton(
                        onPressed: () async {
                          setState(() {
                            status = 'Carregando...';
                          });
                          await AudioPlayerChopinzinhofm.startAudio;
                          setState(() {
                            status = 'Demo app';
                          });
                        },
                        child: Text('Play')),
                    FlatButton(
                        onPressed: () {
                          AudioPlayerChopinzinhofm.stopAudio;
                        },
                        child: Text('Stop')),
                  ],
                )
              ],
            ),
          ],
        )),
      ),
    );
  }
}
